@@ -3,7 +3,7 @@
 
 (function() {
   'use strict';
-  
+
   /**
    * @ngInject
    */
@@ -44,7 +44,7 @@
     this.go = function(module, form) {
       if (form.$valid) {
         // Close sidenav on small devices
-        if (!$mdMedia('gt-sm'))
+        if (!$mdMedia('gt-md'))
           $mdSidenav('left').close();
         $state.go('preferences.' + module);
       }
@@ -62,9 +62,15 @@
         });
     };
 
+    this.resetCalendarCategories = function(form) {
+      this.preferences.defaults.SOGoCalendarCategories = _.keys($window.defaultCalendarCategories);
+      this.preferences.defaults.SOGoCalendarCategoriesColorsValues = _.values($window.defaultCalendarCategories);
+      form.$setDirty();
+    };
+
     this.addCalendarCategory = function(form) {
-      this.preferences.defaults.SOGoCalendarCategoriesColors[l('New category')] = "#aaa";
       this.preferences.defaults.SOGoCalendarCategories.push(l('New category'));
+      this.preferences.defaults.SOGoCalendarCategoriesColorsValues.push("#aaa");
       focus('calendarCategory_' + (this.preferences.defaults.SOGoCalendarCategories.length - 1));
       form.$setDirty();
     };
@@ -74,9 +80,8 @@
     };
 
     this.removeCalendarCategory = function(index, form) {
-      var key = this.preferences.defaults.SOGoCalendarCategories[index];
       this.preferences.defaults.SOGoCalendarCategories.splice(index, 1);
-      delete this.preferences.defaults.SOGoCalendarCategoriesColors[key];
+      this.preferences.defaults.SOGoCalendarCategoriesColorsValues.splice(index, 1);
       form.$setDirty();
     };
 
@@ -202,10 +207,10 @@
         form.$setDirty();
       });
     };
-    
+
     this.editMailFilter = function(ev, index, form) {
       var filter = angular.copy(this.preferences.defaults.SOGoSieveFilters[index]);
-      
+
       $mdDialog.show({
         templateUrl: 'editFilter?filter=' + index,
         controller: 'FiltersDialogController',
@@ -388,7 +393,7 @@
 
       return false;
     };
-    
+
     this.changePassword = function() {
       Authentication.changePassword(this.passwords.newPassword).then(function() {
         var alert = $mdDialog.alert({
