@@ -373,7 +373,7 @@
     // Add 'isOwned' and 'isSubscription' attributes based on active user (TODO: add it server-side?)
     this.isOwned = Calendar.activeUser.isSuperUser || this.owner == Calendar.activeUser.login;
     this.isSubscription = !this.isRemote && this.owner != Calendar.activeUser.login;
-    if (angular.isUndefined(this.$shadowData)) {
+    if (angular.isUndefined(this.$shadowData) || !this.$shadowData.id) {
       // Make a copy of the data for an eventual reset
       this.$shadowData = this.$omit();
     }
@@ -386,6 +386,8 @@
    * @returns a promise of the calendar id
    */
   Calendar.prototype.$id = function() {
+    var _this = this;
+
     if (this.id) {
       // Object already unwrapped
       return Calendar.$q.when(this.id);
@@ -393,7 +395,10 @@
     else {
       // Wait until object is unwrapped
       return this.$futureCalendarData.then(function(calendar) {
-        return calendar.id;
+        if (calendar.id)
+          return calendar.id;
+        else
+          return Calendar.$q.reject();
       });
     }
   };
@@ -498,18 +503,20 @@
    * @returns a promise of the HTTP operation
    */
   Calendar.prototype.$save = function() {
-    var _this = this;
+    var _this = this,
+        d = Calendar.$q.defer();
 
-    return Calendar.$$resource.save(this.id, this.$omit()).then(function(data) {
+    Calendar.$$resource.save(this.id, this.$omit()).then(function(data) {
       // Make a copy of the data for an eventual reset
       _this.$shadowData = _this.$omit();
-      return data;
+      return d.resolve(data);
     }, function(data) {
-      Calendar.$log.error(JSON.stringify(data, undefined, 2));
       // Restore previous version
       _this.$reset();
-      return data;
+      return d.reject(data);
     });
+
+    return d.promise;
   };
 
   /**
@@ -547,14 +554,26 @@
    * @returns a promise of the HTTP operation
    */
   Calendar.prototype.export = function() {
-    var options;
+    var options, resource, ownerPaths, realOwnerId, path, index;
 
     options = {
       type: 'application/octet-stream',
       filename: this.name + '.ics'
     };
 
-    return Calendar.$$resource.download(this.id + '.ics', 'export', null, options);
+    if (this.isSubscription) {
+      index = this.urls.webDavICSURL.indexOf('/dav/');
+      ownerPaths = this.urls.webDavICSURL.substring(index + 5).split(/\//);
+      realOwnerId = ownerPaths[0];
+      resource = Calendar.$$resource.userResource(realOwnerId);
+      path = ownerPaths.splice(ownerPaths.length - 2).join('/');
+    }
+    else {
+      resource = Calendar.$$resource;
+      path = this.id + '.ics';
+    }
+
+    return resource.open(path, 'export', null, options);
   };
 
   /**
@@ -614,7 +633,7 @@
     angular.forEach(this, function(value, key) {
       if (key != 'constructor' &&
           key[0] != '$') {
-        calendar[key] = value;
+        calendar[key] = angular.copy(value);
       }
     });
     return calendar;
